# Code Reference - Custom Information - Extra

The definitions for the "extra" information classes, i.e. fields that apply to the whole dataframe such as author, etc.

## df_file_interchange.ci.extra.base

::: df_file_interchange.ci.extra.base.FIBaseExtraInfo


## df_file_interchange.ci.extra.std_extra

::: df_file_interchange.ci.extra.std_extra.FIStdExtraInfo

